function obj_datagrid_skin(){};
obj_datagrid_skin.prototype.__constructor = function(){
	this._col_width = 15;
};